@@ -19,12 +19,14 @@
 #ifndef AISLERIOT_GAME_H
 #define AISLERIOT_GAME_H
 
-#include <libguile.h>
-
-#include <gdk/gdktypes.h>
+#include <gdk/gdk.h>
 
 #include <libgames-support/games-card.h>
 
+#ifdef HAVE_CLUTTER
+#include <clutter/clutter.h>
+#endif
+
 G_BEGIN_DECLS
 
 /* A slot */
@@ -33,6 +35,11 @@ typedef struct {
   int id;
 
   GByteArray *cards;
+#ifdef HAVE_CLUTTER
+  /* The old state of the cards so we can check for differences */
+  guint old_exposed;
+  GByteArray *old_cards;
+#endif /* HAVE_CLUTTER */
 
   /* the topmost |exposed| cards are shown on the pile */
   guint exposed;
@@ -54,8 +61,13 @@ typedef struct {
   /* The location in pixel units. Filled in by the scaling code. */
   GdkRectangle rect;
 
+#ifdef HAVE_CLUTTER
+  /* Actor for the slot */
+  ClutterActor *slot_renderer;
+#else
   /* GdkPixbuf* or GdkPixmap*, no reference owned */
   GPtrArray *card_images;
+#endif /* HAVE_CLUTTER */
 
   guint expanded_right : 1;
   guint expanded_down : 1;
@@ -80,6 +92,8 @@ typedef struct {
 
 #define AISLERIOT_GAME_ERROR  (aisleriot_game_error_quark ())
 
+#define AISLERIOT_GAME_OPTIONS_MAX (0x7FFFFFFF) /* 31 bits, since we're using int not guint */
+
 typedef struct _AisleriotGame AisleriotGame;
 typedef GObjectClass AisleriotGameClass;
 
@@ -105,8 +119,22 @@ typedef enum {
   LAST_GAME_STATE
 } AisleriotGameState;
 
+typedef enum {
+  AISLERIOT_GAME_OPTION_CHECK,
+  AISLERIOT_GAME_OPTION_RADIO
+} AisleriotGameOptionType;
+
+typedef struct {
+  char *display_name;
+  AisleriotGameOptionType type;
+  guint32 value; /* exactly 1 bit set */
+  gboolean set;
+} AisleriotGameOption;
+
 GQuark aisleriot_game_error_quark (void);
 
+void aisleriot_game_option_free (AisleriotGameOption *option);
+
 GType aisleriot_game_get_type (void);
 
 AisleriotGame *aisleriot_game_new (void);
@@ -165,11 +193,13 @@ gboolean aisleriot_game_button_clicked_lambda (AisleriotGame * game,
 gboolean aisleriot_game_button_double_clicked_lambda (AisleriotGame * game,
                                                       int slot_id);
 
-SCM aisleriot_game_hint_lambda (AisleriotGame * game);
+char *aisleriot_game_get_hint (AisleriotGame *game);
 
-SCM aisleriot_game_get_options_lambda (AisleriotGame * game);
+GList *aisleriot_game_get_options (AisleriotGame * game);
 
-SCM aisleriot_game_apply_options_lambda (AisleriotGame * game, SCM options);
+guint32 aisleriot_game_change_options (AisleriotGame *game,
+                                       guint32 changed_mask,
+                                       guint32 changed_value);
 
 gboolean aisleriot_game_timeout_lambda (AisleriotGame * game);
 
@@ -189,6 +219,13 @@ void aisleriot_game_generate_exception (AisleriotGame * game);
 
 void aisleriot_game_deal_cards (AisleriotGame *game);
 
+void aisleriot_game_get_card_offset (Slot *slot,
+                                     guint card_num,
+                                     gboolean old_cards,
+                                     gint *xoff, gint *yoff);
+
+void aisleriot_game_reset_old_cards (Slot *slot);
+
 G_END_DECLS
 
 #endif /* !AISLERIOT_GAME_H */
