@@ -2,7 +2,7 @@
  * File: chat.c
  * Author: Justin Zaun
  * Project: GGZ GTK Client
- * $Id: chat.c 5930 2007-02-10 10:59:26Z andreasr $
+ * $Id: chat.c 8206 2008-10-27 20:39:34Z thomashpa $
  *
  * This file contains all functions that are chat related.
  *
@@ -32,6 +32,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <strings.h> /* For strcasecmp */
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <sys/types.h>
 #ifdef HAVE_SYS_SOCKET_H
@@ -632,11 +633,11 @@ int chat_checkurl(GtkXText *xtext, char *word)
 
 	/* Check for URLs */
 	if (!strncasecmp (word, "ftp.", 4))
-		return WORD_URL;
+		return WORD_HOST;
 	if (!strncasecmp (word, "ftp://", 6))
 		return WORD_URL;
 	if (!strncasecmp (word, "www.", 4))
-		return WORD_URL;
+		return WORD_HOST;
 	if (!strncasecmp (word, "http://", 7))
 		return WORD_URL;
 	if (!strncasecmp (word, "https://", 8))
@@ -704,14 +705,21 @@ int chat_checkurl(GtkXText *xtext, char *word)
 void chat_word_clicked(GtkXText *xtext, char *word,
         GdkEventButton *event)
 {
+	GError *err = NULL;
+	char *url;
+
 	switch(chat_checkurl(xtext, word))
 	{
 		case WORD_GGZ:
 			login_goto_server(word);
 			break;
 		case WORD_HOST:
+			url = g_strconcat ("http://", word, NULL);
+			gtk_show_uri (NULL, url, GDK_CURRENT_TIME, &err);
+			g_free (url);
+			break;
 		case WORD_URL:
-			support_goto_url(word);
+			gtk_show_uri (NULL, word, GDK_CURRENT_TIME, &err);
 			break;
 		default:
 			break;
