@@ -1,6 +1,7 @@
 /* Games Scores Dialog - Display high scores
  *
  * Copyright (c) 2005 by Callum McKenzie
+ *
  * This library is free software; you can redistribute it and'or modify
  * it under the terms of the GNU Library General Public License as published
  * by the Free Software Foundation; either version 2, or (at your option)
@@ -19,18 +20,21 @@
 
 /* Authors:   Callum McKenzie <callum@physics.otago.ac.nz> */
 
-#include <glib.h>
-#include <glib-object.h>
-
 #ifndef GAMES_SCORES_H
 #define GAMES_SCORES_H
 
+#include <glib.h>
+#include <glib-object.h>
+
 G_BEGIN_DECLS
+
 #include "games-score.h"
 #include "games-scores-backend.h"
+
 /* How many scores get counted as significant. */
 #define GAMES_SCORES_SIGNIFICANT 10
-  typedef struct {
+
+typedef struct {
   gchar *key;			/* A unique identifier (warning: this is used to generate the
 				 * scores file name, so it should match the old domains) */
   gchar *name;			/* A human-readable description. */
@@ -39,17 +43,6 @@ G_BEGIN_DECLS
 typedef void (*GamesScoresCategoryForeachFunc) (GamesScoresCategory * cat,
 						gpointer data);
 
-#define GAMES_SCORES_LAST_CATEGORY {NULL, NULL}
-
-/* All elements get copied so the creator stays the owner. */
-typedef struct {
-  const GamesScoresCategory *categories;	/* Array of categories, terminate
-						 * with GAMES_SCORES_LAST_CATEGORY. */
-  const gchar *deflt;			/* The key of the default category. */
-  const gchar *basename;		/* The base of the filename. The old appname. */
-  GamesScoreStyle style;
-} GamesScoresDescription;
-
 #define GAMES_TYPE_SCORES (games_scores_get_type())
 #define GAMES_SCORES(obj) G_TYPE_CHECK_INSTANCE_CAST((obj), games_scores_get_type(), GamesScores)
 #define GAMES_SCORES_CONST(obj)	G_TYPE_CHECK_INSTANCE_CAST((obj), games_scores_get_type(), GamesScores const)
@@ -58,29 +51,51 @@ typedef struct {
 
 #define GAMES_SCORES_GET_CLASS(obj) G_TYPE_INSTANCE_GET_CLASS((obj), games_scores_get_type(), GamesScoresClass)
 
-typedef struct _GamesScores {
-  GObject parent;
-  struct _GamesScoresPrivate *priv;
-} GamesScores;
+typedef struct _GamesScores         GamesScores;
+typedef struct _GamesScoresPrivate  GamesScoresPrivate;
+typedef struct _GamesScoresClass    GamesScoresClass;
 
-typedef struct _GamesScoresClass {
+struct _GamesScores {
+  GObject parent;
+  GamesScoresPrivate *priv;
+};
+
+struct _GamesScoresClass {
   GObjectClass parent;
-} GamesScoresClass;
+};
 
 GType games_scores_get_type (void);
-GamesScores *games_scores_new (const GamesScoresDescription * description);
+
+GamesScores *games_scores_new (const char *app_name,
+                               const GamesScoresCategory *categories,
+                               int n_categories,
+                               const char *categories_context,
+                               const char *categories_domain,
+                               int default_category_index,
+                               GamesScoreStyle style);
+
 void games_scores_set_category (GamesScores * self, gchar * category);
+
 gint games_scores_add_score (GamesScores * self, GamesScoreValue score);
+
 void games_scores_update_score (GamesScores * self, gchar * new_name);
+
 void games_scores_update_score_name (GamesScores * self, gchar * new_name, gchar * old_name);
+
 GList *games_scores_get (GamesScores * self);
-void games_scores_category_foreach (GamesScores * self,
-				    GamesScoresCategoryForeachFunc func,
-				    gpointer userdata);
+
+void _games_scores_category_foreach (GamesScores * self,
+                                     GamesScoresCategoryForeachFunc func,
+                                     gpointer userdata);
+
 GamesScoreStyle games_scores_get_style (GamesScores * self);
+
 const gchar *games_scores_get_category (GamesScores * self);
-void games_scores_add_category (GamesScores * self, gchar * key,
-				gchar * name);
+
+void games_scores_add_category (GamesScores *self,
+                                const char *key,
+				const char *name);
 
 G_END_DECLS
+
 #endif /* GAMES_SCORES_H */
